# ♄ SATyrn: A SAT Solver Toolbox
[![Build Status](https://travis-ci.org/jeffrey-hokanson/SATyrn.svg?branch=master)](https://travis-ci.org/jeffrey-hokanson/SATyrn)

An interface to SAT solvers.



## See Also

* [pycosat](https://github.com/ContinuumIO/pycosat)
* [pylgl](https://github.com/abfeldman/pylgl)

